@@ -22,12 +22,14 @@ from hypothesis.internal.conjecture.utils import combine_labels
 from hypothesis.strategies._internal.strategies import (
     MappedSearchStrategy,
     SearchStrategy,
+    check_strategy,
     filter_not_satisfied,
 )
+from hypothesis.strategies._internal.utils import cacheable, defines_strategy
 
 
 class TupleStrategy(SearchStrategy):
-    """A strategy responsible for fixed length tuples based on heterogenous
+    """A strategy responsible for fixed length tuples based on heterogeneous
     strategies for each of their elements."""
 
     def __init__(self, strategies):
@@ -60,6 +62,23 @@ class TupleStrategy(SearchStrategy):
         return any(recur(e) for e in self.element_strategies)
 
 
+@cacheable
+@defines_strategy()
+def tuples(*args: SearchStrategy) -> SearchStrategy[tuple]:
+    """Return a strategy which generates a tuple of the same length as args by
+    generating the value at index i from args[i].
+
+    e.g. tuples(integers(), integers()) would generate a tuple of length
+    two with both values an integer.
+
+    Examples from this strategy shrink by shrinking their component parts.
+    """
+    for arg in args:
+        check_strategy(arg)
+
+    return TupleStrategy(args)
+
+
 class ListStrategy(SearchStrategy):
     """A strategy for lists which takes a strategy for its elements and the
     allowed lengths, and generates lists with the correct size and contents."""
